@@ -865,17 +865,19 @@ class WinThread(Thread):
         winproxy.NtQueryInformationThread(self.handle, ThreadQuerySetWin32StartAddress, byref(res), ctypes.sizeof(res))
         return res.value
 
-    @property
-    def teb_base(self):
-        """The address of the thread's TEB
+    def _get_principal_teb_addr(self):
+        # Returns the 64bits TEB on a 64bits computer (syswow process or not)
+        # Returns the 32bits TEB on a 32bits computer
 
-            :type: :class:`int`
-		"""
-        if windows.current_process.bitness == 32 and self.owner.bitness == 64:
+        # If we are wow64 process its means we either
+        # - Want the TEB of a 64b process
+        # - Want the TEB64 of a Wowprocess
+        # It's the same code for both
+        if windows.current_process.is_wow_64:
             restype = rctypes.transform_type_to_remote64bits(THREAD_BASIC_INFORMATION)
             ressize = (ctypes.sizeof(restype))
             # Manual aligned allocation :DDDD
-            nb_qword = (ressize + 8) / ctypes.sizeof(ULONGLONG)
+            nb_qword = int((ressize + 8) / ctypes.sizeof(ULONGLONG))
             buffer = (nb_qword * ULONGLONG)()
             struct_address = ctypes.addressof(buffer)
             if (struct_address & 0xf) not in [0, 8]:
@@ -887,6 +889,33 @@ class WinThread(Thread):
         windows.winproxy.NtQueryInformationThread(self.handle, ThreadBasicInformation, byref(res), ctypes.sizeof(res))
         return res.TebBaseAddress
 
+    @property
+    def teb_base(self):
+        """The address of the thread's TEB. If the owner is a SysWow64 process, return the TEB32.
+
+            :type: :class:`int`
+		"""
+        main_teb_addr = self._get_principal_teb_addr()
+        if not self.owner.is_wow_64:
+            return main_teb_addr
+        # TEB32 is pointed at the begining of the TEB64
+        # TebBase->NtTib.ExceptionList = (PVOID)Teb32Base;
+        return self.owner.read_dword(main_teb_addr)
+
+
+
+    @property
+    def teb_syswow_base(self):
+        """The address of the thread's TEB64 for a SysWow64 process
+
+        :type: :class:`int`
+		"""
+        if not self.owner.is_wow_64:
+            raise ValueError("Not a syswow process")
+        # just return the main TEB
+        return self._get_principal_teb_addr()
+
+
     def exit(self, code=0):
         """Exit the thread"""
         return winproxy.TerminateThread(self.handle, code)
@@ -973,8 +1002,8 @@ class WinProcess(Process):
 
     @classmethod
     def _from_PROCESSENTRY32(cls, entry):
-        #print("_from_PROCESSENTRY32")
-        name = entry.szExeFile.decode()
+        # Temporary encoded name
+        name = entry.szExeFile.encode(errors="backslashreplace")
         pid = entry.th32ProcessID
         ppid = entry.th32ParentProcessID
         return cls(pid=pid, name=name, ppid=ppid)
@@ -1115,6 +1144,9 @@ class WinProcess(Process):
         """
         return injection.execute_python_code(self, pycode)
 
+
+
+
     @utils.fixedpropety
     def peb_addr(self):
         """The address of the PEB
