@@ -29,6 +29,37 @@ from windows.winobject import bits
 
 from windows.dbgprint import dbgprint
 
+
+class UnicodeEnvironment(dict):
+    def __getitem__(self, key):
+        key = key.upper()
+        return super(UnicodeEnvironment, self).__getitem__(key)
+
+    def __delitem__(self, key):
+        key = key.upper()
+        windows.winproxy.SetEnvironmentVariableW(key, None)
+        return super(UnicodeEnvironment, self).__delitem__(key)
+
+    def __contains__(self, key):
+        key = key.upper()
+        return super(UnicodeEnvironment, self).__contains__(key)
+
+    def __setitem__(self, key, value):
+        if value is None:
+            # SetEnvironmentVariableW
+            # If this parameter is NULL, the variable is deleted from the current process's environment.
+            del self[key]
+            return
+        key = key.upper()
+        windows.winproxy.SetEnvironmentVariableW(key, value)
+        return super(UnicodeEnvironment, self).__setitem__(key, value)
+
+    def update(self, *args, **kwargs):
+        for k, v in dict(*args, **kwargs).items():
+            self[k.upper()] = v
+
+    # Setitem -> SetEnvironmement variable
+
 class System(object):
     """The state of the current ``Windows`` system ``Python`` is running on"""
 
@@ -97,6 +128,35 @@ class System(object):
             return 64
         return 32
 
+    @utils.fixedpropety
+    def environ(self):
+        """A unicode version of os.environ
+        Same as os.environ on py3
+        Custom dict built on GetEnvironmentStringsW() on py2
+
+        :type: :class:`dict` -- {unicode: unicode}
+		"""
+        if windows.pycompat.is_py3:
+            return os.environ # Py3 environ is already unicode
+        # Create a unicode wrapper environment
+        return self._create_unicode_environ_dict()
+
+    def _create_unicode_environ_dict(self):
+        rawdictenv = {}
+        curenv = envptr = windows.winproxy.GetEnvironmentStringsW()
+        while True:
+            envstr = ctypes.c_wchar_p(curenv).value
+            if not envstr:
+                break
+            try:
+                key, value = envstr.split("=", 1)
+            except ValueError as e: # No =
+                pass
+            rawdictenv[key.upper()] = value
+            curenv += (len(envstr) + 1) * 2
+        windows.winproxy.FreeEnvironmentStringsW(envptr)
+        return UnicodeEnvironment(rawdictenv)
+
     @utils.fixedpropety
     def wmi(self):
         r"""An object to perform wmi requests to various namespaces
@@ -174,6 +234,23 @@ class System(object):
             winproxy.GetComputerNameA(buf, ctypes.byref(size))
         return buf[:size.value]
 
+    def _computer_name_ex(self, nametype):
+        size = gdef.DWORD(0)
+        try:
+            winproxy.GetComputerNameExW(nametype, None, ctypes.byref(size))
+        except WindowsError as e:
+            if e.winerror != gdef.ERROR_MORE_DATA:
+                raise
+
+        buf = ctypes.create_unicode_buffer(size.value)
+        winproxy.GetComputerNameExW(nametype, buf, ctypes.byref(size))
+        return buf[:size.value]
+
+    @utils.fixedproperty
+    def domain(self):
+        # [WIP] name of the domain joined by the computer, None is no domain joined
+        return self._computer_name_ex(gdef.ComputerNameDnsDomain) or None
+
     @utils.fixedpropety
     def version(self):
         """The version of the system
@@ -423,13 +500,13 @@ class System(object):
     @staticmethod
     def enumerate_processes():
         dbgprint("Enumerating processes with CreateToolhelp32Snapshot", "SLOW")
-        process_entry = gdef.PROCESSENTRY32()
+        process_entry = gdef.PROCESSENTRY32W()
         process_entry.dwSize = ctypes.sizeof(process_entry)
         snap = winproxy.CreateToolhelp32Snapshot(gdef.TH32CS_SNAPPROCESS, 0)
-        winproxy.Process32First(snap, process_entry)
+        winproxy.Process32FirstW(snap, process_entry)
         res = []
         res.append(process.WinProcess._from_PROCESSENTRY32(process_entry))
-        while winproxy.Process32Next(snap, process_entry):
+        while winproxy.Process32NextW(snap, process_entry):
             res.append(process.WinProcess._from_PROCESSENTRY32(process_entry))
         winproxy.CloseHandle(snap)
         return res
@@ -467,12 +544,12 @@ class System(object):
         # One snap for both enum to be prevent race
         snap = winproxy.CreateToolhelp32Snapshot(gdef.TH32CS_SNAPTHREAD | gdef.TH32CS_SNAPPROCESS, 0)
 
-        process_entry = gdef.PROCESSENTRY32()
+        process_entry = gdef.PROCESSENTRY32W()
         process_entry.dwSize = ctypes.sizeof(process_entry)
-        winproxy.Process32First(snap, process_entry)
+        winproxy.Process32FirstW(snap, process_entry)
         processes = []
         processes.append(process.WinProcess._from_PROCESSENTRY32(process_entry))
-        while winproxy.Process32Next(snap, process_entry):
+        while winproxy.Process32NextW(snap, process_entry):
             processes.append(process.WinProcess._from_PROCESSENTRY32(process_entry))
 
         # Forge a dict pid -> process
