@@ -8,7 +8,9 @@ from .iphlpapi import *
 from .kernel32 import *
 from .ktmw32 import *
 from .ntdll import *
+from .netapi32 import *
 from .ole32 import *
+from .oleaut32 import *
 from .oleacc import *
 from .psapi import *
 from .setupapi import *
@@ -19,4 +21,7 @@ from .user32 import *
 from .version import *
 from .virtdisk import *
 from .wevtapi import *
-from .wintrust import *
\ No newline at end of file
+from .winhttp import *
+from .wininet import *
+from .wintrust import *
+from .ws2_32 import *
\ No newline at end of file
