@@ -335,6 +335,8 @@ def GetVersionExA(lpVersionInformation):
 def GetVersionExW(lpVersionInformation):
     return GetVersionExW.ctypes_function(lpVersionInformation)
 
+
+
 ## Hardware
 
 @Kernel32Proxy()
@@ -373,6 +375,14 @@ def GetComputerNameA(lpBuffer, lpnSize):
 def GetComputerNameW(lpBuffer, lpnSize):
     return GetComputerNameW.ctypes_function(lpBuffer, lpnSize)
 
+@Kernel32Proxy()
+def GetComputerNameExA(NameType, lpBuffer, nSize):
+    return GetComputerNameExA.ctypes_function(NameType, lpBuffer, nSize)
+
+@Kernel32Proxy()
+def GetComputerNameExW(NameType, lpBuffer, nSize):
+    return GetComputerNameExW.ctypes_function(NameType, lpBuffer, nSize)
+
 @Kernel32Proxy()
 def GetWindowsDirectoryA(lpBuffer, uSize=None):
     if uSize is None:
@@ -389,6 +399,9 @@ def GetWindowsDirectoryW(lpBuffer, uSize=None):
 def GetProductInfo(dwOSMajorVersion, dwOSMinorVersion, dwSpMajorVersion, dwSpMinorVersion, pdwReturnedProductType):
    return GetProductInfo.ctypes_function(dwOSMajorVersion, dwOSMinorVersion, dwSpMajorVersion, dwSpMinorVersion, pdwReturnedProductType)
 
+
+
+
 ## Other
 
 @Kernel32Proxy(error_check=no_error_check)
@@ -461,7 +474,7 @@ def CreateFileA(lpFileName, dwDesiredAccess=gdef.GENERIC_READ, dwShareMode=0, lp
 
 @Kernel32Proxy(error_check=result_is_handle)
 def CreateFileW(lpFileName, dwDesiredAccess=gdef.GENERIC_READ, dwShareMode=0, lpSecurityAttributes=None, dwCreationDisposition=gdef.OPEN_EXISTING, dwFlagsAndAttributes=gdef.FILE_ATTRIBUTE_NORMAL, hTemplateFile=None):
-    return CreateFileA.ctypes_function(lpFileName, dwDesiredAccess, dwShareMode, lpSecurityAttributes, dwCreationDisposition, dwFlagsAndAttributes, hTemplateFile)
+    return CreateFileW.ctypes_function(lpFileName, dwDesiredAccess, dwShareMode, lpSecurityAttributes, dwCreationDisposition, dwFlagsAndAttributes, hTemplateFile)
 
 @Kernel32Proxy(error_check=result_is_handle)
 def CreateFileTransactedA(lpFileName, dwDesiredAccess, dwShareMode, lpSecurityAttributes, dwCreationDisposition, dwFlagsAndAttributes, hTemplateFile, hTransaction, pusMiniVersion, pExtendedParameter):
@@ -538,6 +551,42 @@ def FindNextFileW(hFindFile, lpFindFileData):
 def FindClose(hFindFile):
     return FindClose.ctypes_function(hFindFile)
 
+@Kernel32Proxy()
+def FindFirstChangeNotificationA(lpPathName, bWatchSubtree, dwNotifyFilter):
+    return FindFirstChangeNotificationA.ctypes_function(lpPathName, bWatchSubtree, dwNotifyFilter)
+
+@Kernel32Proxy()
+def FindFirstChangeNotificationW(lpPathName, bWatchSubtree, dwNotifyFilter):
+    return FindFirstChangeNotificationW.ctypes_function(lpPathName, bWatchSubtree, dwNotifyFilter)
+
+@Kernel32Proxy()
+def FindNextChangeNotification(hChangeHandle):
+    return FindNextChangeNotification.ctypes_function(hChangeHandle)
+
+@Kernel32Proxy()
+def FindCloseChangeNotification(hChangeHandle):
+    return FindCloseChange
+    Notification.ctypes_function(hChangeHandle)
+
+@Kernel32Proxy()
+def FindNextChangeNotification(hChangeHandle):
+    return FindNextChangeNotification.ctypes_function(hChangeHandle)
+
+@Kernel32Proxy()
+def ReadDirectoryChangesW(hDirectory, lpBuffer, nBufferLength, bWatchSubtree, dwNotifyFilter, lpBytesReturned, lpOverlapped, lpCompletionRoutine):
+    return ReadDirectoryChangesW.ctypes_function(hDirectory, lpBuffer, nBufferLength, bWatchSubtree, dwNotifyFilter, lpBytesReturned, lpOverlapped, lpCompletionRoutine)
+
+@Kernel32Proxy()
+def ReadDirectoryChangesExW(hDirectory, lpBuffer, nBufferLength, bWatchSubtree, dwNotifyFilter, lpBytesReturned, lpOverlapped, lpCompletionRoutine, ReadDirectoryNotifyInformationClass):
+    return ReadDirectoryChangesExW.ctypes_function(hDirectory, lpBuffer, nBufferLength, bWatchSubtree, dwNotifyFilter, lpBytesReturned, lpOverlapped, lpCompletionRoutine, ReadDirectoryNotifyInformationClass)
+
+@Kernel32Proxy()
+def LockFile(hFile, dwFileOffsetLow, dwFileOffsetHigh, nNumberOfBytesToLockLow, nNumberOfBytesToLockHigh):
+    return LockFile.ctypes_function(hFile, dwFileOffsetLow, dwFileOffsetHigh, nNumberOfBytesToLockLow, nNumberOfBytesToLockHigh)
+
+@Kernel32Proxy()
+def LockFileEx(hFile, dwFlags, dwReserved, nNumberOfBytesToLockLow, nNumberOfBytesToLockHigh, lpOverlapped):
+    return LockFileEx.ctypes_function(hFile, dwFlags, dwReserved, nNumberOfBytesToLockLow, nNumberOfBytesToLockHigh, lpOverlapped)
 
 ## Tlhelp (snapshoot)
 
@@ -567,6 +616,15 @@ def Process32First(hSnapshot, lpte):
 def Process32Next(hSnapshot, lpte):
     return Process32Next.ctypes_function(hSnapshot, lpte)
 
+@Kernel32Proxy()
+def Process32FirstW(hSnapshot, lppe):
+    return Process32FirstW.ctypes_function(hSnapshot, lppe)
+
+@Kernel32Proxy(error_check=no_error_check)
+def Process32NextW(hSnapshot, lppe):
+    return Process32NextW.ctypes_function(hSnapshot, lppe)
+
+
 ## VEH
 
 @Kernel32Proxy()
@@ -880,4 +938,45 @@ def EnumResourceNamesA(hModule, lpType, lpEnumFunc, lParam):
 
 @Kernel32Proxy()
 def EnumResourceNamesW(hModule, lpType, lpEnumFunc, lParam):
-    return EnumResourceNamesW.ctypes_function(hModule, lpType, lpEnumFunc, lParam)
\ No newline at end of file
+    return EnumResourceNamesW.ctypes_function(hModule, lpType, lpEnumFunc, lParam)
+
+# Environment
+@Kernel32Proxy()
+def GetEnvironmentVariableA(lpName, lpBuffer, nSize):
+    if nSize is None:
+        nSize = ctypes.sizeof(lpBuffer)
+    return GetEnvironmentVariableA.ctypes_function(lpName, lpBuffer, nSize)
+
+@Kernel32Proxy()
+def GetEnvironmentVariableW(lpName, lpBuffer, nSize):
+    if nSize is None:
+        nSize = ctypes.sizeof(lpBuffer)
+    return GetEnvironmentVariableW.ctypes_function(lpName, lpBuffer, nSize)
+
+@Kernel32Proxy()
+def SetEnvironmentVariableA(lpName, lpValue):
+    return SetEnvironmentVariableA.ctypes_function(lpName, lpValue)
+
+@Kernel32Proxy()
+def SetEnvironmentVariableW(lpName, lpValue):
+    return SetEnvironmentVariableW.ctypes_function(lpName, lpValue)
+
+@Kernel32Proxy()
+def GetEnvironmentStringsA():
+    return GetEnvironmentStringsA.ctypes_function()
+
+@Kernel32Proxy()
+def GetEnvironmentStringsW():
+    return GetEnvironmentStringsW.ctypes_function()
+
+@Kernel32Proxy()
+def SetEnvironmentStringsW(NewEnvironment):
+    return SetEnvironmentStringsW.ctypes_function(NewEnvironment)
+
+@Kernel32Proxy()
+def FreeEnvironmentStringsA(penv):
+    return FreeEnvironmentStringsA.ctypes_function(penv)
+
+@Kernel32Proxy()
+def FreeEnvironmentStringsW(penv):
+    return FreeEnvironmentStringsW.ctypes_function(penv)
\ No newline at end of file
